Index: tools/gyp_dart.py |
=================================================================== |
--- tools/gyp_dart.py (revision 13701) |
+++ tools/gyp_dart.py (working copy) |
@@ -22,9 +22,9 @@ |
'-Idart/tools/gyp/all.gypi', 'dart/dart.gyp'] |
if sys.platform == 'win32': |
# Generate Visual Studio 2008 compatible files by default. |
if not os.environ.get('GYP_MSVS_VERSION'): |
- args.extend(['-G', 'msvs_version=2008']) |
+ args.extend(['-G', 'msvs_version=2010']) |
sys.exit(execute(args)) |
@@ -22,9 +22,9 @@ |
'-Idart/tools/gyp/all.gypi', 'dart/dart.gyp'] |
if sys.platform == 'win32': |
- # Generate Visual Studio 2008 compatible files by default. |
+ # Generate Visual Studio 2010 compatible files by default. |
if not os.environ.get('GYP_MSVS_VERSION'): |